@@ -508,13 +508,25 @@ def model_to_idf(
               'used for all ground-contact floor faces. If unspecified, the ground '
               'types will be left as they are. Choose from: UndergroundSlab, '
               'SlabOnGrade, RaisedFloor.', type=str, default='', show_default=True)
+@click.option('--program-name', '-p', help='Optional text to set the name of the '
+              'software that will appear under the programId and ProductName tags '
+              'of the DocumentHistory section. This can be set things like "Ladybug '
+              'Tools" or "Pollination" or some other software in which this gbXML '
+              'export capability is being run. If None, "OpenStudio" will be used.',
+              type=str, default=None, show_default=True)
+@click.option('--program-version', '-v', help='Optional text to set the version of '
+              'the software that will appear under the DocumentHistory section. '
+              'If None, and the program_name is also unspecified, only the version '
+              'of OpenStudio will appear. Otherwise, this will default to "0.0.0" '
+              'given that the version field is required.',
+              type=str, default=None, show_default=True)
 @click.option('--output-file', '-f', help='Optional gbXML file to output the string '
               'of the translation. By default it printed out to stdout', default='-',
               type=click.Path(file_okay=True, dir_okay=False, resolve_path=True))
 def model_to_gbxml_cli(
     model_file, multiplier, plenum, no_ceil_adjacency,
     osw_folder, default_subfaces, triangulate_non_planar, minimal,
-    interior_face_type, ground_face_type, output_file
+    interior_face_type, ground_face_type, program_name, program_version, output_file
 ):
     """Translate a Dragonfly Model to a gbXML file.
 
@@ -533,7 +545,8 @@ def model_to_gbxml_cli(
         model_to_gbxml(
             model_file, osw_folder, full_geometry, no_plenum, ceil_adjacency,
             triangulate_subfaces, permit_non_planar, complete_geometry,
-            interior_face_type, ground_face_type, output_file)
+            interior_face_type, ground_face_type, program_name, program_version,
+            output_file)
     except Exception as e:
         _logger.exception('Model translation failed.\n{}'.format(e))
         sys.exit(1)
@@ -545,7 +558,8 @@ def model_to_gbxml(
     model_file, osw_folder=None, full_geometry=False,
     no_plenum=False, ceil_adjacency=False,
     triangulate_subfaces=False, permit_non_planar=False, complete_geometry=False,
-    interior_face_type='', ground_face_type='', output_file=None,
+    interior_face_type='', ground_face_type='',
+    program_name=None, program_version=None, output_file=None,
     multiplier=True, plenum=True, no_ceil_adjacency=True,
     default_subfaces=True, triangulate_non_planar=True, minimal=True,
 ):
@@ -586,10 +600,16 @@ def model_to_gbxml(
         ground_face_type: Text string for the type to be used for all ground-contact
             floor faces. If unspecified, the ground types will be left as they are.
             Choose from: UndergroundSlab, SlabOnGrade, RaisedFloor.
-        bypass_check: Boolean to note whether the Model should be re-serialized
-            to Python and checked before it is translated to .osm. The check is
-            not needed if the model-json was exported directly from the
-            honeybee-energy Python library. (Default: False).
+        program_name: Optional text to set the name of the software that will
+            appear under the programId and ProductName tags of the DocumentHistory
+            section. This can be set things like "Ladybug Tools" or "Pollination"
+            or some other software in which this gbXML export capability is being
+            run. If None, the "OpenStudio" will be used. (Default: None).
+        program_version: Optional text to set the version of the software that
+            will appear under the DocumentHistory section. If None, and the
+            program_name is also unspecified, only the version of OpenStudio will
+            appear. Otherwise, this will default to "0.0.0" given that the version
+            field is required. (Default: None).
         output_file: Optional gbXML file to output the string of the translation.
             By default it will be returned from this method.
     """
@@ -616,10 +636,12 @@ def model_to_gbxml(
     hb_model = hb_models[0]
 
     # translate the model to a gbXML string
+    triangulate_non_planar = not permit_non_planar
     gbxml_str = model_to_gbxml(
         hb_model, triangulate_non_planar_orphaned=triangulate_non_planar,
         triangulate_subfaces=triangulate_subfaces, full_geometry=complete_geometry,
-        interior_face_type=interior_face_type, ground_face_type=ground_face_type
+        interior_face_type=interior_face_type, ground_face_type=ground_face_type,
+        program_name=program_name, program_version=program_version
     )
 
     # write out the gbXML file
@@ -661,6 +683,18 @@ def model_to_gbxml(
               'of the distance (eg. 0.5ft) or, if no units are provided, the value '
               'will be interpreted in the honeybee model units',
               type=str, default='0.2m', show_default=True)
+@click.option('--program-name', '-p', help='Optional text to set the name of the '
+              'software that will appear under the programId and ProductName tags '
+              'of the DocumentHistory section. This can be set things like "Ladybug '
+              'Tools" or "Pollination" or some other software in which this gbXML '
+              'export capability is being run. If None, "OpenStudio" will be used.',
+              type=str, default=None, show_default=True)
+@click.option('--program-version', '-v', help='Optional text to set the version of '
+              'the software that will appear under the DocumentHistory section. '
+              'If None, and the program_name is also unspecified, only the version '
+              'of OpenStudio will appear. Otherwise, this will default to "0.0.0" '
+              'given that the version field is required.',
+              type=str, default=None, show_default=True)
 @click.option('--osw-folder', '-osw', help='Deprecated input that is no longer used.',
               default=None,
               type=click.Path(file_okay=False, dir_okay=True, resolve_path=True))
@@ -670,7 +704,7 @@ def model_to_gbxml(
 def model_to_trace_gbxml_cli(
     model_file, multiplier, plenum, no_ceil_adjacency,
     single_window, rect_sub_distance, frame_merge_distance,
-    osw_folder, output_file
+    program_name, program_version, osw_folder, output_file
 ):
     """Translate a Dragonfly Model to a TRACE-compatible gbXML file.
 
@@ -686,7 +720,8 @@ def model_to_trace_gbxml_cli(
         detailed_windows = not single_window
         model_to_trace_gbxml(
             model_file, full_geometry, no_plenum, ceil_adjacency, detailed_windows,
-            rect_sub_distance, frame_merge_distance, osw_folder, output_file)
+            rect_sub_distance, frame_merge_distance, osw_folder,
+            program_name, program_version, output_file)
     except Exception as e:
         _logger.exception('Model translation failed.\n{}'.format(e))
         sys.exit(1)
@@ -696,8 +731,8 @@ def model_to_trace_gbxml_cli(
 
 def model_to_trace_gbxml(
     model_file, full_geometry=False, no_plenum=False, ceil_adjacency=False,
-    detailed_windows=False, rect_sub_distance='0.15m',
-    frame_merge_distance='0.2m', osw_folder=None, output_file=None,
+    detailed_windows=False, rect_sub_distance='0.15m', frame_merge_distance='0.2m',
+    program_name=None, program_version=None, osw_folder=None, output_file=None,
     multiplier=True, plenum=True, no_ceil_adjacency=True, single_window=True
 ):
     """Translate a Dragonfly Model to a gbXML file that is compatible with TRACE.
@@ -733,6 +768,16 @@ def model_to_trace_gbxml(
             merged across their frames. This can include the units of the
             distance (eg. 0.5ft) or, if no units are provided, the value will
             be interpreted in the honeybee model units. (Default: 0.2m).
+        program_name: Optional text to set the name of the software that will
+            appear under the programId and ProductName tags of the DocumentHistory
+            section. This can be set things like "Ladybug Tools" or "Pollination"
+            or some other software in which this gbXML export capability is being
+            run. If None, the "OpenStudio" will be used. (Default: None).
+        program_version: Optional text to set the version of the software that
+            will appear under the DocumentHistory section. If None, and the
+            program_name is also unspecified, only the version of OpenStudio will
+            appear. Otherwise, this will default to "0.0.0" given that the version
+            field is required. (Default: None).
         osw_folder: Deprecated input that is no longer used.
         output_file: Optional gbXML file to output the string of the translation.
             By default it will be returned from this method.
@@ -762,7 +807,9 @@ def model_to_trace_gbxml(
     hb_model = _preprocess_model_for_trace(
         hb_model, single_window=single_window, rect_sub_distance=rect_sub_distance,
         frame_merge_distance=frame_merge_distance)
-    gbxml_str = model_to_gbxml(hb_model)
+    gbxml_str = model_to_gbxml(
+        hb_model, program_name=program_name, program_version=program_version
+    )
 
     # write out the gbXML file
     return process_content_to_output(gbxml_str, output_file)
@@ -900,8 +947,27 @@ def model_to_sdd(
         enforce_adj=False)
     hb_model = hb_models[0]
 
+    if geometry_names:  # rename all face geometry so that it is easy to identify
+        hb_model.reset_ids()  # sets the identifiers based on the display_name
+        for room in hb_model.rooms:
+            room.display_name = None
+            for face in room.faces:
+                face.display_name = None
+                for ap in face.apertures:
+                    ap.display_name = None
+                for dr in face.apertures:
+                    dr.display_name = None
+            room.rename_faces_by_attribute()
+            room.rename_apertures_by_attribute()
+            room.rename_doors_by_attribute()
+        hb_model.reset_ids()
+
     # convert the Honeybee model to an OpenStudio Model
-    os_model = model_to_openstudio(hb_model, use_simple_window_constructions=True)
+    os_model = model_to_openstudio(
+        hb_model,
+        use_simple_window_constructions=True,
+        use_resource_names=resource_names
+    )
 
     # write the SDD
     out_path = None
