@@ -741,13 +741,12 @@ class GHEThermalLoop(object):
                 },
                 'ets_model': 'Fifth Gen Heat Pump',
                 'fifth_gen_ets_parameters': {
-                    'supply_water_temperature_building': 15,
                     'chilled_water_supply_temp': 5,
+                    'heating_water_supply_temp': 50,
                     'hot_water_supply_temp': 50,
                     'cop_heat_pump_heating': 2.5,
                     'cop_heat_pump_cooling': 3.5,
-                    'pump_flow_rate': 0.01,
-                    'pump_design_head': 150000,
+                    'cop_heat_pump_hot_water': 2.5,
                     'ets_pump_flow_rate': 0.0005,
                     'ets_pump_head': 10000,
                     'fan_design_flow_rate': 0.25,
@@ -761,27 +760,48 @@ class GHEThermalLoop(object):
         u_temp = self.soil_parameters.undisturbed_temperature \
             if self.soil_parameters._undisturbed_temperature is not None \
             else 'Autocalculate'
+        soil_par = {
+            'conductivity': self.soil_parameters.conductivity,
+            'rho_cp': self.soil_parameters.heat_capacity,
+            'undisturbed_temp': u_temp
+        }
+
+        # add the horizontal piping parameters and central pump parameters
+        hp_par = self.horizontal_pipe_parameters
+        horiz_par = {
+            'hydraulic_diameter_autosized': True,
+            'buried_depth': hp_par.buried_depth,
+            'diameter_ratio': hp_par.diameter_ratio,
+            'pressure_drop_per_meter': int(hp_par.pressure_drop_per_meter),
+            'insulation_conductivity': hp_par.insulation_conductivity,
+            'insulation_thickness': hp_par.insulation_thickness,
+            'rho_cp': hp_par.heat_capacity,
+            'roughness': hp_par.roughness
+        }
+        if isinstance(hp_par.hydraulic_diameter, float):
+            horiz_par['hydraulic_diameter_autosized'] = False
+            horiz_par['hydraulic_diameter'] = hp_par.hydraulic_diameter
+        else:
+            horiz_par['hydraulic_diameter_autosized'] = True
+        pump_par = {}
+        if isinstance(hp_par.pump_design_head, float):
+            pump_par['pump_design_head_autosized'] = False
+            pump_par['pump_design_head'] = hp_par.pump_design_head
+        else:
+            pump_par['pump_design_head_autosized'] = True
+        if isinstance(hp_par.pump_flow_rate, float):
+            pump_par['pump_flow_rate_autosized'] = False
+            pump_par['pump_flow_rate'] = hp_par.pump_flow_rate
+        else:
+            pump_par['pump_flow_rate_autosized'] = True
 
         # add the fifth generation system parameters
-        hp_par = self.horizontal_pipe_parameters
         des_param = {
             'fifth_generation': {
                 'ghe_parameters': self.to_ghe_param_dict(tolerance),
-                'horizontal_piping_parameters': {
-                    'number_of_segments': 1,
-                    'buried_depth': hp_par.buried_depth,
-                    'diameter_ratio': hp_par.diameter_ratio,
-                    'pressure_drop_per_meter': hp_par.pressure_drop_per_meter,
-                    'insulation_conductivity': hp_par.insulation_conductivity,
-                    'insulation_thickness': hp_par.insulation_thickness,
-                    'rho_cp': hp_par.heat_capacity,
-                    'roughness': hp_par.roughness
-                },
-                'soil': {
-                    'conductivity': self.soil_parameters.conductivity,
-                    'rho_cp': self.soil_parameters.heat_capacity,
-                    'undisturbed_temp': u_temp
-                }
+                'central_pump_parameters': pump_par,
+                'horizontal_piping_parameters': horiz_par,
+                'soil': soil_par
             }
         }
         des_dict['district_system'] = des_param
@@ -798,33 +818,27 @@ class GHEThermalLoop(object):
         # compute the geometric constraints of the borehole fields
         geo_pars = []
         for ghe in self.ground_heat_exchangers:
-            ghe_geo = ghe.boundary_2d
-            max_dim = max((ghe_geo.max.x - ghe_geo.min.x, ghe_geo.max.y - ghe_geo.min.y))
-            ang_tol = tolerance / max_dim
-            if ghe_geo.is_rectangle(ang_tol):
-                ghe_dims = (ghe_geo.segments[0].length, ghe_geo.segments[1].length)
-            else:
-                rect_geo = ghe_geo.rectangular_approximation()
-                ghe_dims = (rect_geo.segments[0].length, rect_geo.segments[1].length)
             geo_par = {
                 'ghe_id': ghe.identifier,
-                'ghe_geometric_params': {
-                    'length_of_ghe': max(ghe_dims),
-                    'width_of_ghe': min(ghe_dims)
-                },
-                'borehole': {
-                    'buried_depth': self.borehole_parameters.buried_depth,
-                    'diameter': self.borehole_parameters.diameter
-                },
-                'ground_loads': []
+                'autosized_birectangle_constrained_borefield': {
+                    'b_min': self.borehole_parameters.min_spacing,
+                    'b_max_x': self.borehole_parameters.max_spacing,
+                    'b_max_y': self.borehole_parameters.max_spacing,
+                    'max_height': self.borehole_parameters.max_depth,
+                    'min_height': self.borehole_parameters.min_depth,
+                    'property_boundary': [],  # TODO: remove when GMT is better
+                    'no_go_boundaries': []  # TODO: remove when GMT is better
+                }
             }
             geo_pars.append(geo_par)
 
         # return a dictionary with all of the information
+        fluid_con = 0 if self.fluid_parameters.fluid_type == 'Water' else \
+            self.fluid_parameters.concentration
         return {
             'fluid': {
                 'fluid_name': self.fluid_parameters.fluid_type,
-                'concentration_percent': self.fluid_parameters.concentration,
+                'concentration_percent': fluid_con,
                 'temperature': self.fluid_parameters.temperature
             },
             'grout': {
@@ -843,13 +857,6 @@ class GHEThermalLoop(object):
             'simulation': {
                 'num_months': self.design_parameters.month_count
             },
-            'geometric_constraints': {
-                'b_min': self.borehole_parameters.min_spacing,
-                'b_max': self.borehole_parameters.max_spacing,
-                'max_height': self.borehole_parameters.max_depth,
-                'min_height': self.borehole_parameters.min_depth,
-                'method': 'rectangle'
-            },
             'design': {
                 'method': self.design_parameters.method.upper(),
                 'flow_rate': self.design_parameters.flow_rate,
@@ -857,7 +864,11 @@ class GHEThermalLoop(object):
                 'max_eft': self.design_parameters.max_eft,
                 'min_eft': self.design_parameters.min_eft
             },
-            'ghe_specific_params': geo_pars
+            'borehole': {
+                'buried_depth': self.borehole_parameters.buried_depth,
+                'diameter': self.borehole_parameters.diameter
+            },
+            'borefields': geo_pars
         }
 
     def duplicate(self):
@@ -923,22 +934,6 @@ class GHEThermalLoop(object):
         assert thermal_load.header.unit == 'W', 'Expected load data collection to be in Watts. ' \
             'Got {}.'.format(thermal_load.header.unit)
 
-        # process the input geometry into the format needed for GHEDesigner
-        site_boundaries, site_holes = [], []
-        for face in site_geometry:
-            bnd_poly = Polygon2D([Point2D(pt.x, pt.y) for pt in face.boundary])
-            bnd_poly = bnd_poly.remove_colinear_vertices(tolerance)
-            if bnd_poly.is_clockwise:
-                bnd_poly.reverse()
-            site_boundaries.append([[pt.x, pt.y] for pt in bnd_poly])
-            if face.has_holes:
-                for hole in face.holes:
-                    hole_poly = Polygon2D([Point2D(pt.x, pt.y) for pt in hole])
-                    hole_poly = hole_poly.remove_colinear_vertices(tolerance)
-                    if hole_poly.is_clockwise:
-                        hole_poly.reverse()
-                    site_holes.append([[pt.x, pt.y] for pt in hole_poly])
-
         # set defaults if any of the inputs are unspecified
         soil = soil_parameters if soil_parameters is not None else SoilParameter()
         fluid = fluid_parameters if fluid_parameters is not None else FluidParameter()
@@ -950,57 +945,87 @@ class GHEThermalLoop(object):
         u_temp = 18.3 if soil._undisturbed_temperature is None \
             else soil.undisturbed_temperature
 
+        # loop through the geometries and format them for input to GHEDesigner
+        ghe_objs, topology = {}, []
+        for i, face in enumerate(site_geometry):
+            # add the geometry to the topology
+            top_obj = {'type': 'ground_heat_exchanger', 'name': 'ghe{}'.format(i)}
+            topology.append(top_obj)
+            # process the input geometry into the format needed for GHEDesigner
+            bnd_poly = Polygon2D([Point2D(pt.x, pt.y) for pt in face.boundary])
+            bnd_poly = bnd_poly.remove_colinear_vertices(tolerance)
+            if bnd_poly.is_clockwise:
+                bnd_poly.reverse()
+            site_boundary = [[pt.x, pt.y] for pt in bnd_poly]
+            if face.has_holes:
+                site_holes = []
+                for hole in face.holes:
+                    hole_poly = Polygon2D([Point2D(pt.x, pt.y) for pt in hole])
+                    hole_poly = hole_poly.remove_colinear_vertices(tolerance)
+                    if hole_poly.is_clockwise:
+                        hole_poly.reverse()
+                    site_holes.append([[pt.x, pt.y] for pt in hole_poly])
+            # create the object for the ground heat exchanger
+            ghe_obj = {
+                'flow_rate': design.flow_rate,
+                'flow_type': 'BOREHOLE',
+                'grout': {
+                    'conductivity': soil.grout_conductivity,
+                    'rho_cp': soil.grout_heat_capacity
+                },
+                'soil': {
+                    'conductivity': soil.conductivity,
+                    'rho_cp': soil.heat_capacity,
+                    'undisturbed_temp': u_temp
+                },
+                'pipe': {
+                    'inner_diameter': pipe.inner_diameter,
+                    'outer_diameter': pipe.outer_diameter,
+                    'shank_spacing': pipe.shank_spacing,
+                    'roughness': pipe.roughness,
+                    'conductivity': pipe.conductivity,
+                    'rho_cp': pipe.heat_capacity,
+                    'arrangement': pipe.arrangement.upper()
+                },
+                'borehole': {
+                    'buried_depth': borehole.buried_depth,
+                    'diameter': borehole.diameter
+                },
+                'geometric_constraints': {
+                    'b_min': borehole.min_spacing,
+                    'b_max_x': borehole.max_spacing,
+                    'b_max_y': borehole.max_spacing,
+                    'property_boundary': site_boundary,
+                    'no_go_boundaries': site_holes,
+                    'method': 'BIRECTANGLECONSTRAINED'
+                },
+                'design': {
+                    'max_eft': design.max_eft,
+                    'min_eft': design.min_eft,
+                    'max_height': borehole.max_depth,
+                    'min_height': borehole.min_depth
+                },
+                'loads': {
+                    'load_values': thermal_load.values
+                }
+            }
+            ghe_objs['ghe{}'.format(i)] = ghe_obj
+
         # return a dictionary with all of the inputs
         return {
+            'version': 2,
+            'topology': topology,
             'fluid': {
-                'fluid_name': fluid.fluid_type,
+                'fluid_name': fluid.fluid_type.upper(),
                 'concentration_percent': fluid.concentration,
                 'temperature': fluid.temperature
             },
-            'grout': {
-                'conductivity': soil.grout_conductivity,
-                'rho_cp': soil.grout_heat_capacity
+            'simulation_control': {
+                'sizing_run': True,
+                'hourly_run': False,
+                'sizing_months': design.month_count
             },
-            'soil': {
-                'conductivity': soil.conductivity,
-                'rho_cp': soil.heat_capacity,
-                'undisturbed_temp': u_temp
-            },
-            'pipe': {
-                'inner_diameter': pipe.inner_diameter,
-                'outer_diameter': pipe.outer_diameter,
-                'shank_spacing': pipe.shank_spacing,
-                'roughness': pipe.roughness,
-                'conductivity': pipe.conductivity,
-                'rho_cp': pipe.heat_capacity,
-                'arrangement': pipe.arrangement.upper()
-            },
-            'borehole': {
-                'buried_depth': borehole.buried_depth,
-                'diameter': borehole.diameter
-            },
-            'simulation': {
-                'num_months': design.month_count
-            },
-            'geometric_constraints': {
-                'b_min': borehole.min_spacing,
-                'b_max_x': borehole.max_spacing,
-                'b_max_y': borehole.max_spacing,
-                'max_height': borehole.max_depth,
-                'min_height': borehole.min_depth,
-                'property_boundary': site_boundaries,
-                'no_go_boundaries': site_holes,
-                'method': 'BIRECTANGLECONSTRAINED'
-            },
-            'design': {
-                'flow_rate': design.flow_rate,
-                'flow_type': 'BOREHOLE',
-                'max_eft': design.max_eft,
-                'min_eft': design.min_eft
-            },
-            'loads': {
-                'ground_loads': thermal_load.values
-            }
+            'ground_heat_exchanger': ghe_objs
         }
 
     @staticmethod
@@ -1109,7 +1134,9 @@ class FourthGenThermalLoop(object):
         * hot_water_setpoint
     """
     __slots__ = (
-        '_identifier', '_display_name', '_chilled_water_setpoint', '_hot_water_setpoint')
+        '_identifier', '_display_name',
+        '_chilled_water_setpoint', '_hot_water_setpoint',
+    )
 
     def __init__(self, identifier, chilled_water_setpoint=6, hot_water_setpoint=54):
         """Initialize GHEThermalLoop."""
